# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com), and this project adheres to [Semantic Versioning](https://semver.org).

## Unreleased

## v0.1.2 - 2023-07-05

### Added
- Add support for retrieving zones
- Add support for retrieving specific vehicle by id

## v0.1.1 - 2023-07-04

### Fixed
- Resolve issue with no JSON content on 401 response

## v0.1.0 - 2023-07-04

### Added
- Initial release
